var indexSectionsWithContent =
{
  0: "acdefghilmnoprstuvw▶✅🎪🎯📌📚🔢🔧🔨🛡🧩",
  1: "cfglmostu",
  2: "acefhimstw",
  3: "cfipruv",
  4: "csu",
  5: "cu",
  6: "c",
  7: "acdimoprstuv▶✅🎪🎯📌📚🔢🔧🔨🛡🧩",
  8: "acdefilmnoprstuvw"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "functions",
  3: "variables",
  4: "typedefs",
  5: "enums",
  6: "enumvalues",
  7: "groups",
  8: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Functions",
  3: "Variables",
  4: "Typedefs",
  5: "Enumerations",
  6: "Enumerator",
  7: "Modules",
  8: "Pages"
};

